@@ -1506,6 +1506,11 @@ def mine_git_repo(git_repo_dir, sqlite_db_file, commits=[],
                             "previously paused run with identical settings is required.")
     else:
         print("Found no database on provided path. Starting from scratch.")
+        try:
+            repo_url = git_repo.repo.remotes.origin.url
+        except:
+            repo_url = git_repo_dir
+        
         with sqlite3.connect(sqlite_db_file) as con:
             con.execute("""CREATE TABLE _metadata ('created with',
                                                    'repository',
@@ -1523,14 +1528,13 @@ def mine_git_repo(git_repo_dir, sqlite_db_file, commits=[],
                                 :method,
                                 :extract_text)""",
                         {'version': 'git2net ' + str(__version__),
-                         'repository': git_repo.repo.remotes.origin.url,
+                         'repository': repo_url,
                          'date': datetime.datetime.now().strftime('%Y-%m-%d %H:%M:%S'),
                          'method': 'blocks' if use_blocks else 'lines',
                          'extract_text': str(extract_text)})
             con.commit()
             p_commits = set()
-
-
+            
     # commits in the currently mined repository
     if all_branches:
         c_commits = set(c.hash for c in
@@ -1538,6 +1542,7 @@ def mine_git_repo(git_repo_dir, sqlite_db_file, commits=[],
     else:
         c_commits = set(c.hash for c in
                         pydriller.GitRepository(git_repo_dir).get_list_commits())
+                
     if not commits:
         # unprocessed commits
         if all_branches:
@@ -1549,17 +1554,18 @@ def mine_git_repo(git_repo_dir, sqlite_db_file, commits=[],
             raise Exception("At least one provided commit does not exist in the repository.")
         commits = [git_repo.get_commit(h) for h in commits]
         u_commits = [c for c in commits if c.hash not in p_commits]
-
-    current_branch = git_repo.repo.active_branch.name
-    for c in p_commits.intersection(c_commits):
-        b = con.execute("SELECT branches FROM commits WHERE hash = (:hash)", {'hash': c}).fetchall()[0][0]
-        b = set(b.split(','))
-        if current_branch not in b:
-            b.add(current_branch)
-            con.execute("UPDATE commits SET branches = (:branches) WHERE hash = (:hash)",
-                           {'branches': ','.join(b), 'hash': c})
-    con.commit()
-
+        
+    if all_branches:
+        current_branch = git_repo.repo.active_branch.name
+        for c in p_commits.intersection(c_commits):
+            b = con.execute("SELECT branches FROM commits WHERE hash = (:hash)", {'hash': c}).fetchall()[0][0]
+            b = set(b.split(','))
+            if current_branch not in b:
+                b.add(current_branch)
+                con.execute("UPDATE commits SET branches = (:branches) WHERE hash = (:hash)",
+                               {'branches': ','.join(b), 'hash': c})
+        con.commit()
+    
     if extraction_settings['no_of_processes'] > 1:
         _process_repo_parallel(git_repo_dir, sqlite_db_file, u_commits, extraction_settings)
     else:
